import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import { Spin } from "antd";
import BasicMessageListStore from "./BasicMessageListStore";
import NoRecordsMessage from "../NoRecordsMessage";
import BasicMessageItem from "@dashboard/components/BasicMessageItem";
import CreateMessage from "@dashboard/components/BasicMessageList/CreateMessage";

export interface BasicMessageListProps {
  connectionId: string | null;
}

const BasicMessageList: React.FC<BasicMessageListProps> = observer(
  ({ connectionId }) => {
    const [store] = useState(() => new BasicMessageListStore());

    useEffect(() => {
      store.loadAll(connectionId);

      // Todo. Code for gateway-api
      // const unsubscribe = api.subscribeToBasicMessages((message) => {
      //   if (connectionId === message.connectionId) {
      //     store.items.push(message);
      //   }
      // });
      // return () => {
      //   unsubscribe();
      // };
    }, [store, connectionId]);
    return (
      <div>
        {store.items.map((p) => (
          <BasicMessageItem key={p.id} item={p} />
        ))}
        {!store.loading && !store.items.length && <NoRecordsMessage />}
        {store.loading && <Spin />}

        {connectionId && (
          <div>
            <CreateMessage
              onCreateMessage={(message) =>
                store.sendMessage(connectionId, message)
              }
            />
          </div>
        )}
      </div>
    );
  },
);

export default BasicMessageList;
