import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import { Form, Input, Button } from "antd";
import api from "@dashboard/engine-api";
import { toast } from "react-toastify";
import Modal, { FcProps } from "@dashboard/components/Modal";
import s from "./styles.module.scss";
import displayError from "@dashboard/utils/displayError";

export interface NewCredentialDefDialogProps {
  onCredDefCreated: (credDef: unknown) => void;
}

const NewCredentialDefDialog = observer(
  ({ setTitle, onClose, data }: FcProps<NewCredentialDefDialogProps>) => {
    useEffect(() => {
      setTitle("Add new credetial definition");
    }, [setTitle]);
    const [loading, setLoading] = useState(false);
    const onFinish = async ({
      schemaId,
      tag,
    }: {
      schemaId: string;
      tag: string;
    }) => {
      try {
        setLoading(true);

        const schema = await api.getSchemaById({ id: schemaId });
        if (!schema) {
          throw new Error("Schema with specified id not found");
        }

        const credDef = await api.createCredentialDefinition({
          schemaId,
          tag,
        });
        console.log(credDef);
        toast.success(`New credential definition created`);
        data.onCredDefCreated(credDef);
        onClose();
      } catch (e: unknown) {
        displayError(e);
      }
      setLoading(false);
    };

    return (
      <Modal.Body>
        <div className={s.body}>
          <Form
            layout="vertical"
            initialValues={{
              schemaId: "",
              tag: "",
            }}
            onFinish={onFinish}
            autoComplete="off"
          >
            <Form.Item
              label="Schema Id"
              name="schemaId"
              rules={[{ required: true, message: "Please enter schemaId!" }]}
            >
              <Input />
            </Form.Item>
            <Form.Item
              label="Credential definition name"
              name="tag"
              rules={[{ required: true, message: "Please enter name!" }]}
            >
              <Input />
            </Form.Item>

            <div className={s.footerActions}>
              <Button type="primary" htmlType="submit" disabled={loading}>
                Create
              </Button>
              <Button
                className={s.cancelButton}
                onClick={onClose}
                disabled={loading}
              >
                Close
              </Button>
            </div>
          </Form>
        </div>
      </Modal.Body>
    );
  },
);

export default NewCredentialDefDialog;
