import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import { Button, Input, Space, Spin } from "antd";
import { Link, useNavigate } from "react-router-dom";
import ConnectionListStore from "./ConnectionListStore";
import config from "@dashboard/routes/config";
import ConnectionItem from "@dashboard/components/ConnectionItem";
import modalStore from "@dashboard/store/modalStore";
import NoRecordsMessage from "@dashboard/components/NoRecordsMessage";
import PageWithSidebar from "@dashboard/components/PageWithSidebar";
import PageTitle from "@dashboard/components/PageTitle";
import { runInAction } from "mobx";
import s from "./styles.module.scss";

const ConnectionListPage = observer(() => {
  const [store] = useState(() => new ConnectionListStore());

  const navigate = useNavigate();

  useEffect(() => {
    store.getAll();
  }, [store]);

  return (
    <PageWithSidebar>
      <h2>Actions</h2>
      <Space>
        <Link to={config.connection_create.getLink()}>
          <Button type="primary">New contact</Button>
        </Link>
        <Button
          onClick={() => {
            modalStore.openReceiveInvitationDialog({
              onInvitationReceived: (connRecord) => {
                navigate(config.connection_view.getLink(connRecord.id!));
              },
            });
          }}
        >
          Accept invitation
        </Button>
      </Space>
      <PageTitle>Contacts</PageTitle>
      <div>
        <Space direction="horizontal">
          <div>Search:</div>
          <Input
            className={s.searchInput}
            value={store.searchQuery}
            onChange={(e) => {
              runInAction(() => (store.searchQuery = e.target.value));
            }}
          />
        </Space>
        <div>
          {store.filteredList.map((p) => (
            <ConnectionItem
              key={p.id}
              item={p}
              onClick={() => navigate(config.connection_view.getLink(p.id!))}
            />
          ))}
          {!store.loading && store.filteredList.length === 0 && (
            <NoRecordsMessage />
          )}
          {store.loading && <Spin />}
        </div>
      </div>
    </PageWithSidebar>
  );
});

export default ConnectionListPage;
