import { makeAutoObservable, runInAction } from "mobx";
import { toast } from "react-toastify";
import api, { ConnectionRecordDto } from "@dashboard/engine-api";
import displayError from "@dashboard/utils/displayError";

class ConnectionViewPageStore {
  public loading = false;
  public connection: ConnectionRecordDto | null = null;
  constructor() {
    makeAutoObservable(this);
  }

  public async load(id: string) {
    runInAction(() => (this.loading = true));
    try {
      const record = await api.getConnectionById(id);
      runInAction(() => {
        this.connection = record;
        this.loading = false;
      });
    } catch (e: unknown) {
      displayError(e);
      runInAction(() => (this.loading = false));
    }
  }

  public async deleteConnection(id: string) {
    runInAction(() => (this.loading = true));
    try {
      await api.deleteConnectionById(id);
      runInAction(() => {
        this.loading = false;
      });
      toast.success("Contact deleted successfully");
      return true;
    } catch (e: unknown) {
      displayError(e);
      runInAction(() => (this.loading = false));
      return false;
    }
  }
}

export type { ConnectionViewPageStore };

export default ConnectionViewPageStore;
