import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import { useNavigate, useParams } from "react-router-dom";
import ConnectionViewPageStore from "./ConnectionViewPageStore";
import ConnectionItem from "@dashboard/components/ConnectionItem";
import { Button, Space, Spin } from "antd";
import JsonDetails from "@dashboard/components/JsonDetails";
import CredentialList from "@dashboard/components/CredentialList";
import ProofList from "@dashboard/components/ProofList";
import modalStore from "@dashboard/store/modalStore";
import BasicMessageList from "@dashboard/components/BasicMessageList";
import PageWithSidebar from "@dashboard/components/PageWithSidebar";
import PageTitle from "@dashboard/components/PageTitle";
import route from "@dashboard/routes/config";

const ConnectionViewPage = observer(() => {
  const { id } = useParams() as { id: string };
  const [store] = useState(() => new ConnectionViewPageStore());
  const navigate = useNavigate();

  useEffect(() => {
    store.load(id);
  }, [store, id]);
  return (
    <PageWithSidebar>
      <h2>Actions</h2>
      <Space direction="horizontal">
        <Button
          onClick={() => {
            modalStore.openOfferCredentialDialog({
              connectionId: id,
              onCredentialOffered: (cred) => {
                setTimeout(() => {
                  window.location.reload();
                }, 3000);
              },
            });
          }}
        >
          Offer credential
        </Button>
        <Button
          onClick={() => {
            modalStore.openRequestProofDialog({
              connectionId: id,
              onProofRequested: (proofRequest) => {
                setTimeout(() => {
                  window.location.reload();
                }, 3000);
              },
            });
          }}
        >
          Request proof
        </Button>
        <Button
          danger
          onClick={() => {
            modalStore.openConfirmDialog({
              title: "Are you sure you want to delete this contact?",
              dangerOk: true,
              description: "",
              onOk: async (e) => {
                const result = await store.deleteConnection(id);
                if (result) {
                  e.close();
                  navigate(route.connection_list.getLink());
                }
              },
            });
          }}
        >
          Delete contact
        </Button>
      </Space>
      <PageTitle>Connection</PageTitle>
      {store.loading && <Spin />}
      {!store.loading && store.connection && (
        <div>
          <ConnectionItem item={store.connection} />
        </div>
      )}

      <h3>Credentials</h3>
      <CredentialList connectionId={id} />

      <h3>Proofs</h3>
      <ProofList connectionId={id} />

      <h3>Messages</h3>
      <BasicMessageList connectionId={id} />

      <JsonDetails object={store.connection} />
    </PageWithSidebar>
  );
});

export default ConnectionViewPage;
