import React, { useEffect } from "react";
import { useNavigate, useParams } from "react-router-dom";
import { observer } from "mobx-react";
import useGlobalAuth from "@dashboard/hooks/useGlobalAuth";
import config from "@dashboard/routes/config";
import Page from "@dashboard/components/Page";
import PageTitle from "@dashboard/components/PageTitle";
import { Spin } from "antd";

const RedirectWithTokenPage = observer(() => {
  const { token } = useParams();
  const auth = useGlobalAuth();
  const navigate = useNavigate();

  useEffect(() => {
    async function signInWithToken(token: string | undefined) {
      try {
        await auth.setToken(token as string);
      } catch (e) {
        console.error(e);
      }
      navigate(config.connection_list.getLink(), { replace: true });
    }

    signInWithToken(token);
  }, [token, auth, navigate]);

  return (
    <Page>
      <PageTitle>Authenticating...</PageTitle>
      <h3>You will shortly be redirected to the dashboard.</h3>
      <Spin />
    </Page>
  );
});

export default RedirectWithTokenPage;
