import {
  Injectable,
  InternalServerErrorException,
  Logger,
} from "@nestjs/common";
import {
  ClientProxy,
  ClientProxyFactory,
  Transport,
} from "@nestjs/microservices";
import { ConfigService } from "@nestjs/config";
import { IConnectionManagerConfig } from "@ocm-engine/config";
import { GatewayAcceptedResponseDto, ConnectionEvent } from "@ocm-engine/dtos";
import { lastValueFrom } from "rxjs";

@Injectable()
export class ConnectionManagerClient {
  private client: ClientProxy;
  private cmConfig: IConnectionManagerConfig;
  private readonly logger: Logger = new Logger(ConnectionManagerClient.name);

  constructor(configService: ConfigService) {
    this.cmConfig = configService.get<IConnectionManagerConfig>("cm")!;

    this.client = ClientProxyFactory.create({
      transport: Transport.TCP,
      options: {
        host: this.cmConfig.host,
        port: this.cmConfig.port,
      },
    });
  }

  async sendPayload<T>({
    pattern,
    payload,
  }: {
    pattern: string;
    payload: {
      data: T;
      type: ConnectionEvent;
      source: string;
    };
  }): Promise<GatewayAcceptedResponseDto> {
    this.logger.debug(
      `sending payload to connection manager ${JSON.stringify(
        payload,
        null,
        2,
      )}`,
    );

    return lastValueFrom(this.client.send(pattern, payload)).catch((e) => {
      throw new InternalServerErrorException(e.message);
    });
  }
}
